<?php

namespace Realestate\Payment\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Realestate\Payment\Models\Payment;

class PaymentPolicy
{

    /**
     * Determine if the given user can view the payment.
     *
     * @param UserPolicyInterface $authUser
     * @param Payment $payment
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Payment $payment)
    {
        if ($authUser->canDo('payment.payment.view') && $authUser->isAdmin()) {
            return true;
        }

        return $payment->user_id == user_id() && $payment->user_type == user_type();
    }

    /**
     * Determine if the given user can create a payment.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('payment.payment.create');
    }

    /**
     * Determine if the given user can update the given payment.
     *
     * @param UserPolicyInterface $authUser
     * @param Payment $payment
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Payment $payment)
    {
        if ($authUser->canDo('payment.payment.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $payment->user_id == user_id() && $payment->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given payment.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Payment $payment)
    {
        return $payment->user_id == user_id() && $payment->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given payment.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Payment $payment)
    {
        if ($authUser->canDo('payment.payment.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given payment.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Payment $payment)
    {
        if ($authUser->canDo('payment.payment.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
